<?php

/**
 * Buttons section
 */
Kirki::add_section('buttons', array(
	'title'          => esc_attr__('Buttons', 'audiocast-pro'),
	'priority'       => 15,
	'panel'          => 'appearance'
));

/**
 * Button text
 */
Kirki::add_field('audiocast_pro_options', array(
	'type'        => 'typography',
	'settings'    => 'btn_text',
	'label'       => esc_attr__('Typography', 'audiocast-pro'),
	'section'     => 'buttons',
	'default'     => array(
		'font-family'    => 'Heebo',
		'variant'        => '700',
		'font-size'      => '13px',
		'line-height'    => '1',
		'letter-spacing' => '0',
		'text-transform' => 'uppercase'
	),
	'output'       => array(
		array(
			'element'  => audiocast_pro_button_selector()
		),
	),
));

/**
 * Button color
 */
Kirki::add_field('audiocast_pro_options', array(
	'type'        => 'color',
	'settings'    => 'btn_color',
	'label'       => esc_attr__('Color', 'audiocast-pro'),
	'section'     => 'buttons',
	'default'     => '#ffffff',
	'choices'     => array(
		'alpha' => true,
	),
	'output'      => array(
		array(
			'element'  => audiocast_pro_button_selector(),
			'property' => 'color',
			'exclude'  => array('#ffffff')
		),
	),
	'transport'   => 'auto',
));

/**
 * Button color: Hover
 */
Kirki::add_field('audiocast_pro_options', array(
	'type'        => 'color',
	'settings'    => 'btn_color_hover',
	'label'       => esc_attr__('Color: Hover', 'audiocast-pro'),
	'section'     => 'buttons',
	'default'     => '#ffffff',
	'choices'     => array(
		'alpha' => true,
	),
	'output'      => array(
		array(
			'element'  => implode(':hover, ', audiocast_pro_button_selector()),
			'property' => 'color',
			'exclude'  => array('#ffffff')
		),
	),
	'transport'   => 'auto',
));

/**
 * Button background color
 */
Kirki::add_field('audiocast_pro_options', array(
	'type'        => 'color',
	'settings'    => 'btn_bg_color',
	'label'       => esc_attr__('Background Color', 'audiocast-pro'),
	'section'     => 'buttons',
	'default'     => '#2910d2',
	'choices'     => array(
		'alpha' => true,
	),
	'output'      => array(
		array(
			'element'  => audiocast_pro_button_selector(),
			'property' => 'background-color',
			'exclude'  => array('#2910d2')
		),
	),
	'transport'   => 'auto',
));

/**
 * Button background color: Hover
 */
Kirki::add_field('audiocast_pro_options', array(
	'type'        => 'color',
	'settings'    => 'btn_bg_hover',
	'label'       => esc_attr__('Background Color: Hover', 'audiocast-pro'),
	'section'     => 'buttons',
	'default'     => '#393939',
	'choices'     => array(
		'alpha' => true,
	),
	'output'      => array(
		array(
			'element'  => implode(':hover, ', audiocast_pro_button_selector()),
			'property' => 'background-color',
			'exclude'  => array('#393939')
		),
	),
	'transport'   => 'auto',
));

/**
 * Button height
 */
Kirki::add_field('audiocast_pro_options', array(
	'type'        => 'slider',
	'settings'    => 'btn_height',
	'label'       => esc_attr__('Button Height', 'audiocast-pro'),
	'description' => esc_attr__('Control the padding in pixels above and below your button text.', 'audiocast-pro'),
	'section'     => 'buttons',
	'default'     => '15',
	'choices'      => array(
		'min'  => 0,
		'max'  => 30,
		'step' => 1,
	),
	'output'      => array(
		array(
			'element'  => audiocast_pro_button_selector(),
			'property' => 'padding-top',
			'units'    => 'px',
			'exclude'  => array('15')
		),
		array(
			'element'  => audiocast_pro_button_selector(),
			'property' => 'padding-bottom',
			'units'    => 'px',
			'exclude'  => array('15')
		),
	),
	'transport'    => 'auto',
));

/**
 * Button width
 */
Kirki::add_field('audiocast_pro_options', array(
	'type'        => 'slider',
	'settings'    => 'btn_width',
	'label'       => esc_attr__('Button Width', 'audiocast-pro'),
	'description' => esc_attr__('Control the padding in pixels to the left and right of your button text.', 'audiocast-pro'),
	'section'     => 'buttons',
	'default'     => '53',
	'choices'      => array(
		'min'  => 0,
		'max'  => 100,
		'step' => 1,
	),
	'output'      => array(
		array(
			'element'  => audiocast_pro_button_selector(),
			'property' => 'padding-left',
			'units'    => 'px',
			'exclude'  => array('53')
		),
		array(
			'element'  => audiocast_pro_button_selector(),
			'property' => 'padding-right',
			'units'    => 'px',
			'exclude'  => array('53')
		),
	),
	'transport'    => 'auto',
));

/**
 * Button border radius
 */
Kirki::add_field('audiocast_pro_options', array(
	'type'        => 'slider',
	'settings'    => 'btn_radius',
	'label'       => esc_attr__('Button Shape', 'audiocast-pro'),
	'description' => esc_attr__('Control the shape of the button.', 'audiocast-pro'),
	'section'     => 'buttons',
	'default'     => '2',
	'choices'      => array(
		'min'  => 0,
		'max'  => 50,
		'step' => 1,
	),
	'output'      => array(
		array(
			'element'  => audiocast_pro_button_selector(),
			'property' => 'border-radius',
			'units'    => 'px',
			'exclude'  => array('2')
		),
	),
	'transport'    => 'auto',
));
