<?php

/**
 * Custom meta box layout.
 */

/**
 * Get the post layout based on the given post ID.
 */
function audiocast_pro_get_post_layout($post_id) {

    // Get the post layout.
    $layout = get_post_meta($post_id, '_post_layout', true);

    // Return the layout if one is found. Otherwise, return 'default'.
    return (!empty($layout) ? $layout : 'default');
}

/**
 * Registers new meta box.
 */
function audiocast_pro_post_layouts_box() {

    $screens = ['post', 'page'];
    $screens = apply_filters('audiocast_pro_post_layouts_screen', $screens);
    foreach ($screens as $screen) {
        add_meta_box(
            'audiocast_pro_post_layouts',       // Unique ID
            esc_html__('Layouts', 'outbuilt'),  // Box title
            'audiocast_pro_post_layouts_html',  // Content callback, must be of type callable
            $screen,                            // Post type
            'side'                              // Context
        );
    }
}
add_action('add_meta_boxes', 'audiocast_pro_post_layouts_box');

/**
 * Displays the content of the meta boxes.
 */
function audiocast_pro_post_layouts_html($post) {
    $post_layout = audiocast_pro_get_post_layout($post->ID);
    wp_nonce_field('audiocast_pro_layout_save', 'audiocast_pro_layout_nonce');
?>

    <p><?php esc_html_e('Setup the layout for this page.', 'outbuilt'); ?>
    <p>
        <label>
            <input type="radio" name="audiocast_pro_layout" id="audiocast_pro_layout" value="default" <?php checked($post_layout, 'default'); ?> />
            <?php esc_html_e('Default', 'outbuilt'); ?>
        </label>
    </p>
    <p>
        <label>
            <input type="radio" name="audiocast_pro_layout" id="audiocast_pro_layout" value="right-sidebar" <?php checked($post_layout, 'right-sidebar'); ?> />
            <?php esc_html_e('Right Sidebar', 'outbuilt'); ?>
        </label>
    </p>
    <p>
        <label>
            <input type="radio" name="audiocast_pro_layout" id="audiocast_pro_layout" value="left-sidebar" <?php checked($post_layout, 'left-sidebar'); ?> />
            <?php esc_html_e('Left Sidebar', 'outbuilt'); ?>
        </label>
    </p>
    <p>
        <label>
            <input type="radio" name="audiocast_pro_layout" id="audiocast_pro_layout" value="full-width" <?php checked($post_layout, 'full-width'); ?> />
            <?php esc_html_e('Full Width', 'outbuilt'); ?>
        </label>
    </p>
    <p>
        <label>
            <input type="radio" name="audiocast_pro_layout" id="audiocast_pro_layout" value="full-width-narrow" <?php checked($post_layout, 'full-width-narrow'); ?> />
            <?php esc_html_e('Full Width Narrow', 'outbuilt'); ?>
        </label>
    </p>
<?php
}

/**
 * Saves the metadata.
 */
function audiocast_pro_post_layouts_box_save($post_id) {

    // Bail if we're doing an auto save
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
        return;

    // if our nonce isn't there, or we can't verify it, bail
    if (!isset($_POST['audiocast_pro_layout_nonce']) || !wp_verify_nonce($_POST['audiocast_pro_layout_nonce'], 'audiocast_pro_layout_save'))
        return;

    // if our current user can't edit this post, bail
    if (!current_user_can('edit_posts'))
        return;

    if (array_key_exists('audiocast_pro_layout', $_POST)) {
        update_post_meta(
            $post_id,
            '_post_layout',
            $_POST['audiocast_pro_layout']
        );
    } else {
        delete_post_meta($post_id, '_post_layout');
    }
}
add_action('save_post', 'audiocast_pro_post_layouts_box_save', 10, 2);
