<?php

/**
 * Template area
 */

/**
 * Header
 */
function audiocast_pro_header() {
    get_template_part('partials/header/header');
}
add_action('audiocast_pro_header', 'audiocast_pro_header');

/**
 * Footer template
 */
function audiocast_pro_footer() {
    get_template_part('sidebar', 'footer');
}
add_action('audiocast_pro_footer', 'audiocast_pro_footer');

/**
 * Archive header informations.
 */
function audiocast_pro_archive_header() {
?>

    <?php if (is_home()) : ?>
        <div class="archive-header">
            <div class="archive-content">
                <?php the_archive_title('<h1 class="archive-title">', '</h1>'); ?>
            </div>
        </div><!-- .archive-header -->
    <?php endif; ?>

    <?php if (is_archive() && !is_search() && !is_post_type_archive('podcast')) : ?>
        <div class="archive-header">
            <div class="archive-content">
                <?php if (is_author()) echo get_avatar(get_the_author_meta('ID')); ?>
                <?php the_archive_title('<h1 class="archive-title">', '</h1>'); ?>
            </div>
        </div><!-- .archive-header -->
    <?php endif; ?>

    <?php if (is_search()) : ?>
        <div class="archive-header">
            <div class="archive-content">
                <span class="browse"><?php esc_html_e('Search Results for', 'audiocast-pro'); ?></span>
                <h1 class="archive-title"><?php echo get_search_query(); ?></h1>
            </div>
        </div><!-- .archive-header -->
    <?php endif; ?>

    <?php
}
add_action('audiocast_pro_header', 'audiocast_pro_archive_header', 10);

/**
 * Latest podcast episode
 */
function audiocast_pro_latest_podcast() {
    // Only show content on Podcast archive
    if (is_post_type_archive('podcast') || is_page_template('page-templates/home-podcast.php')) {

        // Define query arguments
        $args = [
            'post_type' => 'podcast',
            'posts_per_page' => 1
        ];

        // Call the query
        $query = new WP_Query($args);

        if ($query->have_posts()) { ?>
            <div class="latest-podcast">
                <div class="container">

                    <div class="posts-list">
                        <?php while ($query->have_posts()) : $query->the_post(); ?>
                            <article id="post-<?php the_ID(); ?>" <?php post_class('entry-list'); ?>>

                                <?php audiocast_pro_post_thumbnail('audiocast-post-list'); ?>

                                <div class="entry-wrapper">

                                    <header class="entry-header">

                                        <h4><?php esc_html_e('Latest Episode', 'audiocast-pro'); ?></h4>

                                        <?php the_title(sprintf('<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url(get_permalink())), '</a></h2>'); ?>

                                    </header>

                                    <div class="entry-summary">
                                        <?php the_excerpt(); ?>
                                    </div>

                                    <span class="more-link-wrapper">
                                        <a href="<?php the_permalink(); ?>" class="more-link"><?php esc_html_e('Read More', 'audiocast-pro'); ?></a>
                                    </span>

                                </div>

                            </article><!-- #post-## -->

                        <?php endwhile; ?>
                    </div>

                </div>
            </div>
<?php  }
    }
}
add_action('audiocast_pro_header', 'audiocast_pro_latest_podcast', 10);
